<?php
// $Horde: kronolith/lib/Members.php,v 1.00 2002/07/15 14:18:24 jvandal Exp $

/**
 * This class provides an interface to all members a user might
 * have. Its methods take care of any site-specific restrictions
 * configured in prefs.php and conf.php.
 *
 * @author  Joel Vandal <jvandal@infoteck.qc.ca>
 * @version $Revision: 1.00 $
 * @since   Horde 3.0
 * @package kronolith.member
 */
class Members {

    /**
     * Array containing all the user's members.
     * @var array $members
     */
    var $member = array();

    /**
     * A pointer to the user's standard member.
     * This one is used by the methods returning values
     * if no other one is specified.
     * @var integer $default
     */
    var $default = 0;

    /**
     * Array containing all of the properties in this member,
     * excluding the id.
     * @var array $properties
     */
    var $properties = array();

    /**
     * Reference to the prefs object that this member points to.
     * @var object Prefs $prefs
     */
    var $prefs;

    /**
     * Reads all the user's members from the prefs object or builds
     * a new member from the standard values given in prefs.php.
     *
     * @param optional string $user  If specified, we read another user's
     *                               members instead of the current user.
     */
    function Members($calendar = null)
    {
	global $prefs ;
	
	$calx = @unserialize($prefs->getValue('calendars')) ;
        $members = @unserialize($calx[$calendar]['member']);
	
        if (is_array($members)) {
            $this->members = $members;
        }
    }

    /**
     * Saves all members in the prefs backend.
     */
    function save()
    {
//	$_calendar->setValue('member', serialize($_member->members), $edit_calendar);
//	$_calendar->save();
	// $this->prefs->setValue('member', serialize($this->members));
    }

    /**
     * Adds a new empty member to the array of members.
     * @return integer      The pointer to the created member
     */
    function add()
    {
        $this->members[] = array();
        return count($this->members) - 1;
    }

    /**
     * Remove an member from the array of members
     * @param integer $member The pointer to the member to be removed
     * @return array            The removed member
     */
    function delete($member)
    {
        $deleted = array_splice($this->members, $member, 1);
        foreach ($this->members as $id => $null) {
            if ($this->setDefault($id)) {
                break;
            }
        }
        $this->save();
        return $deleted;
    }

    /**
     * Returns a pointer to the current default member.
     * @return integer      The pointer to the current default member
     */
    function getDefault()
    {
        return $this->default;
    }

    /**
     * Sets the current default member.
     * If the member doesn't exist, the old default member
     * stays the same.
     * @param integer $member     The pointer to the new default member
     * @return boolean              True on success, false on failure
     */
    function setDefault($member)
    {
        if (isset($this->members[$member])) {
            $this->default = $member;
            return true;
        } else {
            return false;
        }
    }

    /**
     * Returns a property from one of the members. If this value doesn't exist
     * or is locked, the property is retrieved from the prefs backend.
     * @param string $key           The property to retrieve.
     * @param integer $member     (optional) The member to retrieve the property from
     * @return mixed                The value of the property.
     */
    function getValue($key, $member = null)
    {
        if (!isset($member) || !isset($this->members[$member])) {
            $member = $this->default;
        }

//        if (!isset($this->members[$member][$key]) || $this->prefs->isLocked($key)) {
//            $val = $this->prefs->getValue($key);
//        } else {
          $val = $this->members[$member][$key];
//        }

        return $val;
    }

    /**
     * Returns an array with the specified property from all existing
     * members.
     * @param string $key       The property to retrieve.
     * @return array            The array with the values from all members
     */
    function getAll($key)
    {

        $list = array();
        foreach ($this->members as $member => $null) {
            $list[$member] = $this->getValue($key, $member);
        }
        return $list;
    }

    /**
     * Sets a property with a specified value.
     * @param string $key       The property to set
     * @param mixed $val        The value to which the property should be set
     * @param integer $member (optional) The member to set the property in
     * @return boolean          True on success, false on failure (property was locked)
     */
    function setValue($key, $val, $member = null)
    {
        if (!isset($member)) {
            $member = $this->default;
        }

	$this->members[$member][$key] = $val;
	
	return true;
    }


    /**
     * Returns true if the given address belongs to one of the members.
     *
     * @param string $key          The member key to search.
     * @param string $value        The value to search for in $key.
     *
     * @return boolean             True if the $value was found in $key.
     */
    function hasValue($key, $valueA)
    {
        $list = $this->getAll($key);
        foreach ($list as $valueB) {
            if (strpos(strtolower($valueA), strtolower($valueB)) !== false) {
                return true;
            }
        }
        return false;
    }

}
?>
